Equatorial class

Equatorial coordinates referenced to the equator and equinox of date.

Constructors

Equatorial(double ra, double dec)
const

Properties

dec double
Declination in radians.
final
hashCode int
The hash code for this object.
no setterinherited
ra double
Right ascension in radians.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited