Horizontal class

Horizontal coordinates referenced to the observer's horizon.

Constructors

Horizontal(double az, double alt)
const

Properties

alt double
Altitude in radians, positive above horizon.
final
az double
Azimuth in radians, measured westward from south.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited