binary library

Functions

apparentEccentricity(double e, double i, double w) double
Apparent eccentricity from true orbital elements.
meanAnomaly(double year, double t, double p) double
Mean anomaly of a binary star.
position(double e, double a, double i, double omega, double w, double eAnom) → ({double rho, double theta})
Apparent position angle and angular distance of binary components.