eclipse library

Constants

annular → const int
annularTotal → const int
none → const int
partial → const int
penumbral → const int
total → const int
umbral → const int

Functions

lunar(double year) → ({double gamma, double jmax, double mag, double rho, double sdPartial, double sdPenumbral, double sdTotal, double sigma, int type})
Lunar eclipse nearest decimal year.
solar(double year) → ({bool central, double gamma, double jmax, double mag, double p, int type, double u})
Solar eclipse nearest decimal year.