globe
library
Functions
-
approxAngularDistance(double lat1, double lon1, double lat2, double lon2)
→ double
-
Cosine of angular distance between two geographic points.
-
approxLinearDistance(double angularDist)
→ double
-
Approximate linear distance on Earth surface in km.
-
distance(double lat1, double lon1, double lat2, double lon2, {double er = earthEr, double fl = earthFl})
→ double
-
Distance between two points on an ellipsoid in km.
-
eccentricity(double fl)
→ double
-
Eccentricity of a meridian.
-
geocentricLatitudeDifference(double phi)
→ double
-
Geographic latitude minus geocentric latitude (radians).
-
oneDegreeOfLatitude(double rm)
→ double
-
Length of one degree of latitude at a given meridian curvature radius
rm (km).
-
oneDegreeOfLongitude(double rp)
→ double
-
Length of one degree of longitude at a given parallel radius
rp (km).
-
parallaxConstants(double phi, double h, {double er = earthEr, double fl = earthFl})
→ ({double rhoCosPrime, double rhsSinPhiPrime})
-
Parallax constants ρ sin φ′ and ρ cos φ′.
-
polarRadius(double er, double fl)
→ double
-
Polar radius in km.
-
radiusAtLatitude(double phi, {double er = earthEr, double fl = earthFl})
→ double
-
Radius of the parallel of latitude
phi in km.
-
radiusOfCurvature(double phi, {double er = earthEr, double fl = earthFl})
→ double
-
Radius of curvature of meridian at latitude
phi in km.
-
rho(double phi)
→ double
-
Distance from Earth center to point on ellipsoid at latitude
phi.