moon library

Classes

MoonPhysical
Internal computation state for Moon physical ephemeris.

Properties

selenographic Map<String, Ecliptic>
Selenographic coordinates of some lunar features (Table 53.A).
final

Functions

physical(double jde, Planet earth) → ({Ecliptic cMoon, Ecliptic cSun, double p})
Physical returns quantities for physical observation of the Moon.
sunAltitude(Ecliptic cOnMoon, Ecliptic cSun) double
Altitude of the Sun above the lunar horizon.
sunrise(Ecliptic cOnMoon, double jde, Planet earth) double
Time of sunrise for a point on the Moon near the given jde.
sunset(Ecliptic cOnMoon, double jde, Planet earth) double
Time of sunset for a point on the Moon near the given jde.