MoonPhysical class

Internal computation state for Moon physical ephemeris.

Constructors

MoonPhysical(double jde)

Properties

hashCode int
The hash code for this object.
no setterinherited
jde double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

lib(double lambda, double beta) → ({double b, double l})
Combined optical and physical librations.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pa(double lambda, double beta, double b) double
Position angle of Moon's axis of rotation.
sun(double lambda, double beta, double delta, Planet earth) → ({double b, double l})
Selenographic coordinates of the Sun.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited