moonnode library

Functions

ascending(double year) double
JDE of the Moon's ascending node passage nearest the given decimal year.
descending(double year) double
JDE of the Moon's descending node passage nearest the given decimal year.