parallactic library

Functions

diurnalPathAtHorizon(double dec, double phi) double
Angle of a celestial object's diurnal path relative to the horizon at rising or setting.
eclipticAtEquator(double lambda, double eps) double
Angle between the ecliptic and parallels of ecliptic latitude.
eclipticAtHorizon(double eps, double phi, double theta) → ({double i, double lambda1, double lambda2})
Computes how the ecliptic intersects the horizon.
parallacticAngle(double phi, double dec, double h) double
Returns the parallactic angle of a celestial object.
parallacticAngleOnHorizon(double phi, double dec) double
Parallactic angle on the horizon (special case when object rises/sets).