perihelion library

Constants

earth → const int
emBary → const int
jupiter → const int
mars → const int
mercury → const int
neptune → const int
saturn → const int
uranus → const int
venus → const int

Functions

aphelion(int p, double year) double
Approximate JDE of aphelion nearest decimal year for planet p.
perihelion(int p, double year) double
Approximate JDE of perihelion nearest decimal year for planet p.