Planet class

VSOP87 representation of a planet.

Constructors

Planet(int index)
Creates a Planet from a planet index constant.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
position(double jde) → ({double lat, double lon, double range})
Heliocentric position at equinox and ecliptic of date.
position2000(double jde) → ({double lat, double lon, double range})
Heliocentric position at dynamical equinox and ecliptic J2000.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited