solstice library

Functions

december(int y) double
JDE of the December solstice for the given year.
june(int y) double
JDE of the June solstice for the given year.
march(int y) double
JDE of the March equinox for the given year.
september(int y) double
JDE of the September equinox for the given year.