elliptic library

Functions

length1(double a, double e) double
Approximate length of an elliptic orbit (Ramanujan, first approximation).
length2(double a, double e) double
Approximate length of an elliptic orbit (Ramanujan, second approximation).
length4(double a, double e) double
Length of an elliptic orbit by numerical integration (4-point).
position(Planet planet, Planet earth, double jde) → ({double dec, double ra})
Observed equatorial coordinates of a planet.
vAphelion(double a, double e) double
Velocity at aphelion for eccentricity e and semimajor axis a.
velocity(double a, double r) double
Velocity of a body at distance r in an orbit with semimajor axis a.
vPerihelion(double a, double e) double
Velocity at perihelion for eccentricity e and semimajor axis a.