moonphase library
Functions
-
first(
double year) → double -
JDE of First Quarter nearest the given decimal
year. -
full(
double year) → double -
JDE of Full Moon nearest the given decimal
year. -
last(
double year) → double -
JDE of Last Quarter nearest the given decimal
year. -
meanFirst(
double year) → double -
JDE of the mean First Quarter nearest the given decimal
year. -
meanFull(
double year) → double -
JDE of the mean Full Moon nearest the given decimal
year. -
meanLast(
double year) → double -
JDE of the mean Last Quarter nearest the given decimal
year. -
meanNew(
double year) → double -
JDE of the mean New Moon nearest the given decimal
year. -
newMoon(
double year) → double -
JDE of New Moon nearest the given decimal
year.