node2
library
Functions
-
ellipticAscending(double axis, double ecc, double argP, double timeP)
→ ({double jde, double r})
-
Time and distance at ascending node for an elliptic orbit.
-
ellipticDescending(double axis, double ecc, double argP, double timeP)
→ ({double jde, double r})
-
Time and distance at descending node for an elliptic orbit.
-
parabolicAscending(double q, double argP, double timeP)
→ ({double jde, double r})
-
Time and distance at ascending node for a parabolic orbit.
-
parabolicDescending(double q, double argP, double timeP)
→ ({double jde, double r})
-
Time and distance at descending node for a parabolic orbit.